==> aws-cdk-scala_3-0.13.0-sources.jar: io/burkard/cdk/services/sam/cfnFunction/SAMPolicyTemplateProperty.scala <==
package io.burkard.cdk.services.sam.cfnFunction

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SAMPolicyTemplateProperty {

  def apply(
    s3CrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.BucketSAMPTProperty] = None,
    dynamoDbStreamReadPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.TableStreamSAMPTProperty] = None,
    rekognitionReadPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.CollectionSAMPTProperty] = None,
    sesEmailTemplateCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    cloudFormationDescribeStacksPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    filterLogEventsPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.LogGroupSAMPTProperty] = None,
    kmsDecryptPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.KeySAMPTProperty] = None,
    ec2DescribePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    amiDescribePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    snsPublishMessagePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.TopicSAMPTProperty] = None,
    dynamoDbReadPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.TableSAMPTProperty] = None,
    stepFunctionsExecutionPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.StateMachineSAMPTProperty] = None,
    lambdaInvokePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.FunctionSAMPTProperty] = None,
    cloudWatchPutMetricPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    rekognitionDetectOnlyPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    rekognitionNoDataAccessPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.CollectionSAMPTProperty] = None,
    sesBulkTemplatedCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.IdentitySAMPTProperty] = None,
    snsCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.TopicSAMPTProperty] = None,
    elasticsearchHttpPostPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.DomainSAMPTProperty] = None,
    kinesisStreamReadPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.StreamSAMPTProperty] = None,
    dynamoDbCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.TableSAMPTProperty] = None,
    kinesisCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.StreamSAMPTProperty] = None,
    sqsSendMessagePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.QueueSAMPTProperty] = None,
    vpcAccessPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    s3ReadPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.BucketSAMPTProperty] = None,
    sesSendBouncePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.IdentitySAMPTProperty] = None,
    rekognitionWriteOnlyAccessPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.CollectionSAMPTProperty] = None,
    sesCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.IdentitySAMPTProperty] = None,
    rekognitionLabelsPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    sqsPollerPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.QueueSAMPTProperty] = None
  ): software.amazon.awscdk.services.sam.CfnFunction.SAMPolicyTemplateProperty =
    (new software.amazon.awscdk.services.sam.CfnFunction.SAMPolicyTemplateProperty.Builder)
      .s3CrudPolicy(s3CrudPolicy.orNull)
      .dynamoDbStreamReadPolicy(dynamoDbStreamReadPolicy.orNull)
      .rekognitionReadPolicy(rekognitionReadPolicy.orNull)
      .sesEmailTemplateCrudPolicy(sesEmailTemplateCrudPolicy.orNull)
      .cloudFormationDescribeStacksPolicy(cloudFormationDescribeStacksPolicy.orNull)
      .filterLogEventsPolicy(filterLogEventsPolicy.orNull)
      .kmsDecryptPolicy(kmsDecryptPolicy.orNull)
      .ec2DescribePolicy(ec2DescribePolicy.orNull)
      .amiDescribePolicy(amiDescribePolicy.orNull)
      .snsPublishMessagePolicy(snsPublishMessagePolicy.orNull)
      .dynamoDbReadPolicy(dynamoDbReadPolicy.orNull)
      .stepFunctionsExecutionPolicy(stepFunctionsExecutionPolicy.orNull)
      .lambdaInvokePolicy(lambdaInvokePolicy.orNull)
      .cloudWatchPutMetricPolicy(cloudWatchPutMetricPolicy.orNull)
      .rekognitionDetectOnlyPolicy(rekognitionDetectOnlyPolicy.orNull)
      .rekognitionNoDataAccessPolicy(rekognitionNoDataAccessPolicy.orNull)
      .sesBulkTemplatedCrudPolicy(sesBulkTemplatedCrudPolicy.orNull)
      .snsCrudPolicy(snsCrudPolicy.orNull)
      .elasticsearchHttpPostPolicy(elasticsearchHttpPostPolicy.orNull)
      .kinesisStreamReadPolicy(kinesisStreamReadPolicy.orNull)
      .dynamoDbCrudPolicy(dynamoDbCrudPolicy.orNull)
      .kinesisCrudPolicy(kinesisCrudPolicy.orNull)
      .sqsSendMessagePolicy(sqsSendMessagePolicy.orNull)
      .vpcAccessPolicy(vpcAccessPolicy.orNull)
      .s3ReadPolicy(s3ReadPolicy.orNull)
      .sesSendBouncePolicy(sesSendBouncePolicy.orNull)
      .rekognitionWriteOnlyAccessPolicy(rekognitionWriteOnlyAccessPolicy.orNull)
      .sesCrudPolicy(sesCrudPolicy.orNull)
      .rekognitionLabelsPolicy(rekognitionLabelsPolicy.orNull)
      .sqsPollerPolicy(sqsPollerPolicy.orNull)
      .build()
}

==> aws-cdk-scala_3-0.21.0-sources.jar: io/burkard/cdk/services/sam/cfnFunction/SAMPolicyTemplateProperty.scala <==
package io.burkard.cdk.services.sam.cfnFunction

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SAMPolicyTemplateProperty {

  def apply(
    s3CrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.BucketSAMPTProperty] = None,
    dynamoDbStreamReadPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.TableStreamSAMPTProperty] = None,
    rekognitionReadPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.CollectionSAMPTProperty] = None,
    dynamoDbWritePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.TableSAMPTProperty] = None,
    sesEmailTemplateCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    cloudFormationDescribeStacksPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    filterLogEventsPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.LogGroupSAMPTProperty] = None,
    s3WritePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.BucketSAMPTProperty] = None,
    kmsDecryptPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.KeySAMPTProperty] = None,
    ec2DescribePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    amiDescribePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    snsPublishMessagePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.TopicSAMPTProperty] = None,
    dynamoDbReadPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.TableSAMPTProperty] = None,
    stepFunctionsExecutionPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.StateMachineSAMPTProperty] = None,
    lambdaInvokePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.FunctionSAMPTProperty] = None,
    ssmParameterReadPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.ParameterNameSAMPTProperty] = None,
    cloudWatchPutMetricPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    rekognitionDetectOnlyPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    rekognitionNoDataAccessPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.CollectionSAMPTProperty] = None,
    sesBulkTemplatedCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.IdentitySAMPTProperty] = None,
    snsCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.TopicSAMPTProperty] = None,
    elasticsearchHttpPostPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.DomainSAMPTProperty] = None,
    kinesisStreamReadPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.StreamSAMPTProperty] = None,
    dynamoDbCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.TableSAMPTProperty] = None,
    kinesisCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.StreamSAMPTProperty] = None,
    sqsSendMessagePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.QueueSAMPTProperty] = None,
    vpcAccessPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    s3ReadPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.BucketSAMPTProperty] = None,
    awsSecretsManagerGetSecretValuePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.SecretArnSAMPTProperty] = None,
    sesSendBouncePolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.IdentitySAMPTProperty] = None,
    rekognitionWriteOnlyAccessPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.CollectionSAMPTProperty] = None,
    sesCrudPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.IdentitySAMPTProperty] = None,
    rekognitionLabelsPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.EmptySAMPTProperty] = None,
    sqsPollerPolicy: Option[software.amazon.awscdk.services.sam.CfnFunction.QueueSAMPTProperty] = None
  ): software.amazon.awscdk.services.sam.CfnFunction.SAMPolicyTemplateProperty =
    (new software.amazon.awscdk.services.sam.CfnFunction.SAMPolicyTemplateProperty.Builder)
      .s3CrudPolicy(s3CrudPolicy.orNull)
      .dynamoDbStreamReadPolicy(dynamoDbStreamReadPolicy.orNull)
      .rekognitionReadPolicy(rekognitionReadPolicy.orNull)
      .dynamoDbWritePolicy(dynamoDbWritePolicy.orNull)
      .sesEmailTemplateCrudPolicy(sesEmailTemplateCrudPolicy.orNull)
      .cloudFormationDescribeStacksPolicy(cloudFormationDescribeStacksPolicy.orNull)
      .filterLogEventsPolicy(filterLogEventsPolicy.orNull)
      .s3WritePolicy(s3WritePolicy.orNull)
      .kmsDecryptPolicy(kmsDecryptPolicy.orNull)
      .ec2DescribePolicy(ec2DescribePolicy.orNull)
      .amiDescribePolicy(amiDescribePolicy.orNull)
      .snsPublishMessagePolicy(snsPublishMessagePolicy.orNull)
      .dynamoDbReadPolicy(dynamoDbReadPolicy.orNull)
      .stepFunctionsExecutionPolicy(stepFunctionsExecutionPolicy.orNull)
      .lambdaInvokePolicy(lambdaInvokePolicy.orNull)
      .ssmParameterReadPolicy(ssmParameterReadPolicy.orNull)
      .cloudWatchPutMetricPolicy(cloudWatchPutMetricPolicy.orNull)
      .rekognitionDetectOnlyPolicy(rekognitionDetectOnlyPolicy.orNull)
      .rekognitionNoDataAccessPolicy(rekognitionNoDataAccessPolicy.orNull)
      .sesBulkTemplatedCrudPolicy(sesBulkTemplatedCrudPolicy.orNull)
      .snsCrudPolicy(snsCrudPolicy.orNull)
      .elasticsearchHttpPostPolicy(elasticsearchHttpPostPolicy.orNull)
      .kinesisStreamReadPolicy(kinesisStreamReadPolicy.orNull)
      .dynamoDbCrudPolicy(dynamoDbCrudPolicy.orNull)
      .kinesisCrudPolicy(kinesisCrudPolicy.orNull)
      .sqsSendMessagePolicy(sqsSendMessagePolicy.orNull)
      .vpcAccessPolicy(vpcAccessPolicy.orNull)
      .s3ReadPolicy(s3ReadPolicy.orNull)
      .awsSecretsManagerGetSecretValuePolicy(awsSecretsManagerGetSecretValuePolicy.orNull)
      .sesSendBouncePolicy(sesSendBouncePolicy.orNull)
      .rekognitionWriteOnlyAccessPolicy(rekognitionWriteOnlyAccessPolicy.orNull)
      .sesCrudPolicy(sesCrudPolicy.orNull)
      .rekognitionLabelsPolicy(rekognitionLabelsPolicy.orNull)
      .sqsPollerPolicy(sqsPollerPolicy.orNull)
      .build()
}
